triton-windows
A language and compiler for custom Deep Learning operations
What it is and what it does
Triton-windows is a Windows-native fork of the Triton compiler, which allows you to write high-performance GPU kernels in Python and compile them just-in-time for NVIDIA GPUs. It bridges the gap between Python's ease of use and the performance demands of deep learning by letting you write custom operations that standard libraries don't cover, then compiling them directly to GPU code at runtime.
The package is designed specifically for Windows environments where the upstream Triton project did not have native support. It works with torch.compile and Triton's @triton.jit decorator, and passes all unit tests. Installation requires careful environment setup—you must ensure your Python version, PyTorch version, and GPU driver are aligned according to the documented compatibility matrix, and the package provides wheels only for Python 3.10–3.14 on Windows x86-64.
Use it for:
- Accelerate custom deep learning operations on Windows by compiling hand-written GPU kernels instead of relying on standard libraries.
- Optimize matrix multiplication, attention mechanisms, or other compute-intensive layers by writing Triton kernels tailored to your model's needs.
- Use torch.compile with Triton on Windows to automatically fuse and compile operations into efficient GPU code.
- Prototype and deploy GPU-accelerated algorithms on Windows without dropping to lower-level GPU programming or managing low-level GPU memory manually.
Worth the install?
AI-flagged interpretation of the facts on this page — verify before relying
Triton-windows is a Windows port of the Triton compiler that lets you write and compile custom GPU kernels for deep learning workloads on NVIDIA GPUs.
Yes, if you need to write custom GPU kernels on Windows and your NVIDIA GPU and PyTorch version are compatible. The permissive license and active wheel distribution make it straightforward to install. No, if you need ongoing maintenance and support—the original repository is archived, though development continues at https://github.com/triton-lang/triton-windows. Verify PyTorch and CUDA version compatibility before installing.
Install
triton-windows on PyPI
pip
pip install triton-windowsuv
uv add triton-windowspoetry
poetry add triton-windowsInstalling triton-windows
Before you install
Medium install friction: platform-specific wheels for Windows (cp310–cp314), requires matching Python environment and GPU driver setup. Repository is archived; development has moved to https://github.com/triton-lang/triton-windows, but pip installation continues to work.
License in practice
Permissive license (MIT) means you can use this package freely in commercial and private projects without restriction.
Quickstart
pip install triton-windows
import triton
@triton.jit
def kernel(x_ptr, output_ptr, n_elements, BLOCK_SIZE: tl.constexpr):
pid = tl.program_id(axis=0)
block_start = pid * BLOCK_SIZE
offsets = block_start + tl.arange(0, BLOCK_SIZE)
mask = offsets < n_elements
x = tl.load(x_ptr + offsets, mask=mask)
tl.store(output_ptr + offsets, x, mask=mask)
Requires Windows 10 or 11, NVIDIA GPU with supported compute capability, matching PyTorch version (e.g., PyTorch 2.7 requires Triton 3.3), and correct Python environment setup (embedded, system-wide, conda, or venv).
Verify before relying
- Whether AMD GPU support via the referenced pull request is production-ready or experimental.
- Current status and stability of free-threaded Python (3.13t/3.14t) support on Windows.
- Whether Proton profiler limitations affect your profiling workflow.
- Specific GPU compute capability requirements for different Triton versions on Windows.
Package facts
| License | not declared (permissive) |
| Python support | supports the current Python release (<3.15,>=3.10) |
| Install friction | medium — platform-specific wheel |
| Runtime dependencies | 1 — importlib-metadata |
| Maintenance | abandoned — 54 days since the last release |
| Last repo commit | (repository archived) |
| First released | |
| Downloads | 471,577/month — #6,479 on PyPI (30-day window, as of 2026-08-14) |
| Known vulnerabilities | none known (OSV.dev, checked 2026-08-14) |
Evidence: triton_windows-3.7.1.post27-cp310-cp310-win_amd64.whl; triton_windows-3.7.1.post27-cp311-cp311-win_amd64.whl; triton_windows-3.7.1.post27-cp312-cp312-win_amd64.whl; triton_windows-3.7.1.post27-cp313-cp313-win_amd64.whl; triton_windows-3.7.1.post27-cp314-cp314-win_amd64.whl
Keywords: Compiler, Deep Learning
Tags
More Build Tools packages
Provides reusable utilities for Python…
permissive · top 100 on PyPI
tqdmWraps any iterable to display a real-time…
copyleft · top 100 on PyPI
pippip is the standard installer for Python…
permissive · top 100 on PyPI
hatchlingHatchling is a standards-compliant Python build…
permissive · top 100 on PyPI
grpcio-toolsGenerates Python gRPC service stubs and message…
permissive · top 1,000 on PyPI
pre-commitpre-commit is a framework for installing and…
permissive · top 1,000 on PyPI
tokenspeed-tritonTriton is a language and compiler for writing…
permissive · top 5,000 on PyPI
tritonTriton is a language and compiler for writing…
permissive · top 1,000 on PyPI
triton-ascendTriton Ascend is a compiler framework that…
unclear · top 15,000 on PyPI
nvidia-cuda-nvrtc-cu12Provides NVIDIA CUDA NVRTC native runtime…
unclear · top 1,000 on PyPI
nvidia-cuda-nvccProvides the NVIDIA CUDA nvcc compiler for…
unclear · top 5,000 on PyPI
helionHelion is a Python-embedded domain-specific…
unclear · top 15,000 on PyPI
nvidia-cuda-nvcc-cu12Provides the NVIDIA CUDA nvcc compiler for…
unclear · top 5,000 on PyPI
nvidia-cuda-nvrtcProvides NVIDIA CUDA NVRTC (NVIDIA Runtime…
unclear · top 1,000 on PyPI
tritonclienttritonclient is a Python client library for…
permissive · top 5,000 on PyPI
perf-analyzerPerf Analyzer is a CLI tool that measures and…
unclear · top 15,000 on PyPI